@@ -1,16 +1,7 @@
 package WWW::Curl::Simple::Request;
+our $VERSION = '0.100160';
+# ABSTRACT: A small class representing request/response
 
-=head1 NAME
-
-WWW::Curl::Simple::Request - A small class representing request/response
-
-=head1 DESCRIPTION
-
-Just a way to collect things used by both single and multi, and some
-WWW::Curl setup. You shouldn't need to use this class anywhere, although
-C<$curl->perform> returns objects of this class
-
-=cut
 
 
 use Moose;
@@ -20,15 +11,6 @@ use Scalar::Util qw/weaken/;
 
 use namespace::clean -except => 'meta';
 
-=head1 INTERFACE
-
-=head2 ATTRIBUTES
-
-=head3 agent
-
-A String that will be sent as the user-agent string. Defaults to
-
-=cut
 
 has 'agent' => (is => 'rw', isa => 'Str', required => 0, lazy_build => 1);
 
@@ -36,37 +18,15 @@ sub _build_agent {
     return "WWW::Curl::Simple/" . $WWW::Curl::Simple::VERSION;
 }
 
-=head2 METHODS
 
-=head3 body
+has 'body' => (is => 'rw', isa => 'ScalarRef', required => 0);
 
-The body of the response
 
-=cut
+has 'head' => (is => 'rw', isa => 'ScalarRef', required => 0);
 
-has 'body' => (is => 'rw', isa => 'Str', required => 0, default => '');
-
-=head3 head
-
-The head of the response
-
-=cut
-
-has 'head' => (is => 'rw', isa => 'Str', required => 0, default => '');
-
-=head3 request
-
-The HTTP::Request-object that we where created with. 
-
-=cut
 
 has 'request' => (is => 'ro', isa => 'HTTP::Request');
 
-=head3 easy
-
-our WWW::Curl::Easy-object
-
-=cut
 
 has 'easy' => (is => 'rw', isa => 'WWW::Curl::Easy', required => 0, lazy_build => 1);
 
@@ -97,28 +57,20 @@ sub _build_easy {
     if (scalar(@headers)) {
         $curl->setopt(CURLOPT_HTTPHEADER, \@headers);
     }
+    my ($body_ref, $head_ref);
+    $self->body(\$body_ref);
+    $self->head(\$head_ref);
+    open (my $fileb, ">", \$body_ref);
+    $curl->setopt(CURLOPT_WRITEDATA,$fileb);
     
-    $curl->setopt(CURLOPT_HEADERFUNCTION, sub {
-        my $chunk = shift;
-        $self->head($self->head . $chunk);
-        return length($chunk);
-    });
-    $curl->setopt(CURLOPT_WRITEFUNCTION, sub {
-        my $chunk = shift;
-        $self->body($self->body . $chunk);
-        return length($chunk);
-    });
-    
+    my $h = $self->head;
+    open (my $fileh, ">", \$head_ref);
+    $curl->setopt(CURLOPT_WRITEHEADER,$fileh);
+        
     return $curl;
     
 }
 
-=head3 perform
-
-Performs the actuall request trough WWW::Curl::Easy. Used mostly in
-single request land. Will croak on errors.
-
-=cut
 
 sub perform {
     my ($self) = @_;
@@ -133,30 +85,78 @@ sub perform {
     
 }
 
-=head3 response
+
+sub response {
+    my ($self) = @_;
+    my $res = HTTP::Response->parse(${$self->head} . "\r" . ${$self->body});
+    $res->request($self->request);
+    $res->content(${$self->body});
+    return $res;
+}
+
+1;
+__END__
+=pod
+
+=head1 NAME
+
+WWW::Curl::Simple::Request - A small class representing request/response
+
+=head1 VERSION
+
+version 0.100160
+
+=head1 DESCRIPTION
+
+Just a way to collect things used by both single and multi, and some
+WWW::Curl setup. You shouldn't need to use this class anywhere, although
+C<< $curl->perform >> returns objects of this class
+
+=head1 ATTRIBUTES
+
+=head2 agent
+
+A String that will be sent as the user-agent string. Defaults to
+
+=head2 body
+
+The body of the response
+
+=head2 head
+
+The head of the response
+
+=head2 request
+
+The HTTP::Request-object that we where created with. 
+
+=head2 easy
+
+our WWW::Curl::Easy-object
+
+=head1 METHODS
+
+=head2 perform
+
+Performs the actuall request trough WWW::Curl::Easy. Used mostly in
+single request land. Will croak on errors.
+
+=head2 response
 
 Returns a HTTP::Response that represents the response of this object.
 
 Also sets request on the response object to the original request object.
 
-=cut
+=head1 AUTHOR
 
-sub response {
-    my ($self) = @_;
-    my $res = HTTP::Response->parse($self->head . "\r" . $self->body);
-    $res->request($self->request);
-    $res->content($self->body);
-    return $res;
-}
+  Andreas Marienborg <andremar@cpan.org>
 
-=head1 COPYRIGHT & LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2009 Andreas Marienborg, all rights reserved.
-
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+This software is copyright (c) 2010 by Andreas Marienborg.
 
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-1;
\ No newline at end of file
